{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Per-region pindel",
            "requirements": [
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "default": 400,
                    "id": "#main/insert_size"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/normal_bam"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "id": "#main/region_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/tumor_bam"
                }
            ],
            "steps": [
                {
                    "run": "#cat_out.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/pindel/deletions",
                                "#main/pindel/insertions",
                                "#main/pindel/tandems",
                                "#main/pindel/long_insertions",
                                "#main/pindel/inversions"
                            ],
                            "id": "#main/cat/pindel_outs"
                        }
                    ],
                    "out": [
                        "#main/cat/pindel_out"
                    ],
                    "id": "#main/cat"
                },
                {
                    "run": "#pindel.cwl",
                    "in": [
                        {
                            "source": "#main/insert_size",
                            "id": "#main/pindel/insert_size"
                        },
                        {
                            "source": "#main/normal_bam",
                            "id": "#main/pindel/normal_bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/pindel/reference"
                        },
                        {
                            "source": "#main/region_file",
                            "id": "#main/pindel/region_file"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/pindel/tumor_bam"
                        }
                    ],
                    "out": [
                        "#main/pindel/deletions",
                        "#main/pindel/insertions",
                        "#main/pindel/tandems",
                        "#main/pindel/long_insertions",
                        "#main/pindel/inversions"
                    ],
                    "id": "#main/pindel"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/cat/pindel_out",
                    "id": "#main/per_region_pindel_out"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/cat"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:xenial"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "per_chromosome_pindel.out",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat_out.cwl/pindel_outs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat_out.cwl/pindel_out",
                    "outputBinding": {
                        "glob": "per_chromosome_pindel.out"
                    }
                }
            ],
            "id": "#cat_out.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "pindel v0.2.5b8",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/pindel_helper.pl",
                "$(inputs.normal_bam.path)",
                "$(inputs.tumor_bam.path)",
                "$(inputs.insert_size)"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "tmpdirMin": 100000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.4.2"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#pindel.cwl/chromosome"
                },
                {
                    "type": "int",
                    "default": 400,
                    "id": "#pindel.cwl/insert_size"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#pindel.cwl/normal_bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#pindel.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-j"
                    },
                    "id": "#pindel.cwl/region_file"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#pindel.cwl/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_D"
                    },
                    "id": "#pindel.cwl/deletions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_SI"
                    },
                    "id": "#pindel.cwl/insertions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_INV"
                    },
                    "id": "#pindel.cwl/inversions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_LI"
                    },
                    "id": "#pindel.cwl/long_insertions"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "all_TD"
                    },
                    "id": "#pindel.cwl/tandems"
                }
            ],
            "id": "#pindel.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
